@@ -1,11 +1,11 @@
-from pycodehash.hashing import FunctionHasher
-from pycodehash.preprocessing import (
+from pycodehash.python_function import (
     DecoratorStripper,
     DocstringStripper,
     FunctionStripper,
     TypeHintStripper,
     WhitespaceNormalizer,
 )
+from pycodehash.python_function.hashing import FunctionHasher
 from pycodehash.version import __version__
 
 __all__ = [
