@@ -1,6 +1,7 @@
+from pycodehash.sql.comment_filter import CommentFilter
 from pycodehash.sql.default_database_filter import DefaultDatabaseFilter
 from pycodehash.sql.references import extract_table_references
 from pycodehash.sql.sql_hasher import SQLHasher
 from pycodehash.sql.whitespace_filter import WhitespaceFilter
 
-__all__ = ["extract_table_references", "SQLHasher", "WhitespaceFilter", "DefaultDatabaseFilter"]
+__all__ = ["extract_table_references", "SQLHasher", "WhitespaceFilter", "DefaultDatabaseFilter", "CommentFilter"]
